@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="bg">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
 <context>
     <name>AppearancePage</name>
     <message>
@@ -9,132 +7,144 @@
         <translation>Стил:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="27"/>
+        <location filename="../appearancepage.ui" line="59"/>
         <source>Preview</source>
         <translation>Преглед:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="34"/>
+        <location filename="../appearancepage.ui" line="66"/>
         <source>Active palette</source>
         <translation>Активна палитра</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="39"/>
+        <location filename="../appearancepage.ui" line="71"/>
         <source>Inactive palette</source>
         <translation>Неактивна палитра</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="44"/>
+        <location filename="../appearancepage.ui" line="76"/>
         <source>Disabled palette</source>
         <translation>Изключена палитра</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="91"/>
+        <location filename="../appearancepage.ui" line="107"/>
         <source>Palette</source>
         <translation>Палитра</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="102"/>
+        <location filename="../appearancepage.ui" line="118"/>
+        <location filename="../appearancepage.cpp" line="86"/>
         <source>Default</source>
         <translation>По подразбиране</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="112"/>
+        <location filename="../appearancepage.ui" line="128"/>
         <source>Custom</source>
         <translation>Потребителски</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="139"/>
+        <location filename="../appearancepage.ui" line="155"/>
         <source>Color scheme:</source>
         <translation>Цветова схема:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.ui" line="162"/>
+        <location filename="../appearancepage.ui" line="178"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="67"/>
+        <location filename="../appearancepage.ui" line="209"/>
+        <source>Standard dialogs:</source>
+        <translation>Стандартни диалози:</translation>
+    </message>
+    <message>
+        <location filename="../appearancepage.cpp" line="69"/>
         <source>Create</source>
         <translation>Създаване</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="68"/>
+        <location filename="../appearancepage.cpp" line="70"/>
         <source>Edit</source>
         <translation>Редактиране</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="69"/>
+        <location filename="../appearancepage.cpp" line="71"/>
         <source>Create a Copy</source>
         <translation>Създаване на копие</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="70"/>
+        <location filename="../appearancepage.cpp" line="72"/>
         <source>Rename</source>
         <translation>Преименуване</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="72"/>
+        <location filename="../appearancepage.cpp" line="74"/>
         <source>Remove</source>
         <translation>Премахване</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="122"/>
-        <location filename="../appearancepage.cpp" line="196"/>
-        <location filename="../appearancepage.cpp" line="231"/>
+        <location filename="../appearancepage.cpp" line="141"/>
+        <location filename="../appearancepage.cpp" line="215"/>
+        <location filename="../appearancepage.cpp" line="254"/>
         <source>Enter Color Scheme Name</source>
         <translation>Въведете име на цветовата схема</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="122"/>
-        <location filename="../appearancepage.cpp" line="196"/>
-        <location filename="../appearancepage.cpp" line="231"/>
+        <location filename="../appearancepage.cpp" line="141"/>
+        <location filename="../appearancepage.cpp" line="215"/>
+        <location filename="../appearancepage.cpp" line="254"/>
         <source>File name:</source>
         <translation>Име на файл:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="131"/>
-        <location filename="../appearancepage.cpp" line="207"/>
-        <location filename="../appearancepage.cpp" line="241"/>
+        <location filename="../appearancepage.cpp" line="150"/>
+        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="234"/>
+        <location filename="../appearancepage.cpp" line="264"/>
         <source>Error</source>
         <translation>Грешка</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="131"/>
-        <location filename="../appearancepage.cpp" line="207"/>
-        <location filename="../appearancepage.cpp" line="241"/>
+        <location filename="../appearancepage.cpp" line="150"/>
+        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="264"/>
         <source>The color scheme &quot;%1&quot; already exists</source>
         <translation>Цветовата схема &quot;%1&quot; вече съществува</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="149"/>
-        <location filename="../appearancepage.cpp" line="172"/>
-        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="168"/>
+        <location filename="../appearancepage.cpp" line="191"/>
+        <location filename="../appearancepage.cpp" line="249"/>
         <source>Warning</source>
         <translation>Внимание</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="149"/>
-        <location filename="../appearancepage.cpp" line="172"/>
-        <location filename="../appearancepage.cpp" line="226"/>
+        <location filename="../appearancepage.cpp" line="168"/>
+        <location filename="../appearancepage.cpp" line="191"/>
+        <location filename="../appearancepage.cpp" line="249"/>
         <source>The color scheme &quot;%1&quot; is read only</source>
         <translation>Цветовата схема &quot;%1&quot; е само за четене</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="177"/>
+        <location filename="../appearancepage.cpp" line="196"/>
         <source>Confirm Remove</source>
         <translation>Потвърждаване на премахването</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="178"/>
+        <location filename="../appearancepage.cpp" line="197"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
         <translation>Сигурен ли сте, че искате да премахнете цветова схема &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="198"/>
+        <location filename="../appearancepage.cpp" line="217"/>
         <source>%1 (copy)</source>
         <translation>%1 (копиране)</translation>
     </message>
+    <message>
+        <location filename="../appearancepage.cpp" line="234"/>
+        <source>Unable to copy file</source>
+        <translation>Не може да бъде копиран файла</translation>
+    </message>
 </context>
 <context>
     <name>FontConfigDialog</name>
@@ -219,30 +229,30 @@
 <context>
     <name>FontsPage</name>
     <message>
-        <location filename="../fontspage.ui" line="44"/>
-        <location filename="../fontspage.ui" line="64"/>
-        <location filename="../fontspage.ui" line="80"/>
-        <location filename="../fontspage.ui" line="87"/>
+        <location filename="../fontspage.ui" line="47"/>
+        <location filename="../fontspage.ui" line="67"/>
+        <location filename="../fontspage.ui" line="86"/>
+        <location filename="../fontspage.ui" line="93"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../fontspage.ui" line="57"/>
+        <location filename="../fontspage.ui" line="60"/>
         <source>General:</source>
         <translation>Общи:</translation>
     </message>
     <message>
-        <location filename="../fontspage.ui" line="94"/>
+        <location filename="../fontspage.ui" line="100"/>
         <source>Fixed width:</source>
         <translation>Фиксирана ширина:</translation>
     </message>
     <message>
-        <location filename="../fontspage.ui" line="119"/>
+        <location filename="../fontspage.ui" line="125"/>
         <source>Create  fonts.conf</source>
         <translation>Създаване на  fonts.conf</translation>
     </message>
     <message>
-        <location filename="../fontspage.ui" line="126"/>
+        <location filename="../fontspage.ui" line="132"/>
         <source>Remove fonts.conf</source>
         <translation>Премахване на  fonts.conf</translation>
     </message>
@@ -342,6 +352,46 @@
         <source>Activate item on single-click</source>
         <translation>Активиране на елемент с еднократно кликване</translation>
     </message>
+    <message>
+        <location filename="../interfacepage.ui" line="219"/>
+        <source>Toolbar button style:</source>
+        <translation>Стил на бутоните в лентата с инструменти:</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.ui" line="229"/>
+        <source>Mouse wheel scroll lines:</source>
+        <translation>Превъртане на позициите с колелцето на мишката:</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.ui" line="246"/>
+        <source>Show shortcut underlines</source>
+        <translation>Показване на подсказки за бъз достъп</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="47"/>
+        <source>Only display the icon</source>
+        <translation>Покажи само икони</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="48"/>
+        <source>Only display the text</source>
+        <translation>Покажи само текст</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="49"/>
+        <source>The text appears beside the icon</source>
+        <translation>Текстът да се вижда до иконите</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="50"/>
+        <source>The text appears under the icon</source>
+        <translation>Текстът да се вижда под иконите</translation>
+    </message>
+    <message>
+        <location filename="../interfacepage.cpp" line="51"/>
+        <source>Follow the application style</source>
+        <translation>Следвай стила на програмата</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -560,7 +610,7 @@
 <context>
     <name>QSSEditorDialog</name>
     <message>
-        <location filename="../qsseditordialog.cpp" line="45"/>
+        <location filename="../qsseditordialog.cpp" line="46"/>
         <source>%1 - Style Sheet Editor</source>
         <translation>%1 - Редактор на стила на страница</translation>
     </message>
@@ -580,95 +630,121 @@
     <message>
         <location filename="../qsspage.ui" line="66"/>
         <location filename="../qsspage.cpp" line="51"/>
+        <location filename="../qsspage.cpp" line="87"/>
         <source>Edit</source>
         <translation>Редактиране</translation>
     </message>
     <message>
         <location filename="../qsspage.ui" line="76"/>
-        <location filename="../qsspage.cpp" line="52"/>
+        <location filename="../qsspage.cpp" line="53"/>
         <source>Rename</source>
         <translation>Преименуване</translation>
     </message>
     <message>
         <location filename="../qsspage.ui" line="33"/>
-        <location filename="../qsspage.cpp" line="54"/>
+        <location filename="../qsspage.cpp" line="55"/>
         <source>Remove</source>
         <translation>Премахване</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="102"/>
+        <location filename="../qsspage.cpp" line="52"/>
+        <source>Create a Copy</source>
+        <translation>Създаване на копие</translation>
+    </message>
+    <message>
+        <location filename="../qsspage.cpp" line="92"/>
+        <source>View</source>
+        <translation>Преглед</translation>
+    </message>
+    <message>
+        <location filename="../qsspage.cpp" line="106"/>
+        <location filename="../qsspage.cpp" line="251"/>
         <source>File name:</source>
         <translation>Име на файл:</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="102"/>
+        <location filename="../qsspage.cpp" line="106"/>
+        <location filename="../qsspage.cpp" line="251"/>
         <source>Enter Style Sheet Name</source>
         <translation>Въведете име на стила на страница</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="113"/>
-        <location filename="../qsspage.cpp" line="205"/>
-        <location filename="../qsspage.cpp" line="216"/>
+        <location filename="../qsspage.cpp" line="117"/>
+        <location filename="../qsspage.cpp" line="218"/>
+        <location filename="../qsspage.cpp" line="226"/>
+        <location filename="../qsspage.cpp" line="263"/>
+        <location filename="../qsspage.cpp" line="271"/>
         <source>Error</source>
         <translation>Грешка</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="113"/>
+        <location filename="../qsspage.cpp" line="117"/>
         <source>The file &quot;%1&quot; already exists</source>
         <translation>Файлът &quot;%1&quot; вече съществува</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="147"/>
+        <location filename="../qsspage.cpp" line="151"/>
         <source>Confirm Remove</source>
         <translation>Потвърждение на премахването</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="148"/>
+        <location filename="../qsspage.cpp" line="152"/>
         <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
         <translation>Сигурен ли сте, че искате да премахнете стил на страница &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="198"/>
+        <location filename="../qsspage.cpp" line="208"/>
         <source>Rename Style Sheet</source>
         <translation>Преименуване на стил на страница</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="198"/>
+        <location filename="../qsspage.cpp" line="208"/>
         <source>Style sheet name:</source>
         <translation>Име на стил на страница:</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="205"/>
+        <location filename="../qsspage.cpp" line="218"/>
+        <location filename="../qsspage.cpp" line="263"/>
         <source>The style sheet &quot;%1&quot; already exists</source>
         <translation>Стилът на страница &quot;%1&quot; вече съществува</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="216"/>
+        <location filename="../qsspage.cpp" line="226"/>
         <source>Unable to rename file</source>
         <translation>Файлът не може да бъде преименуван</translation>
     </message>
+    <message>
+        <location filename="../qsspage.cpp" line="253"/>
+        <source>%1 (copy).qss</source>
+        <translation>%1 (копиране).qss</translation>
+    </message>
+    <message>
+        <location filename="../qsspage.cpp" line="271"/>
+        <source>Unable to copy file</source>
+        <translation>Не може да бъде копиран файла</translation>
+    </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="60"/>
+        <location filename="../main.cpp" line="62"/>
         <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable</source>
         <translation>Моля, премахнете променливата &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; </translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="65"/>
+        <location filename="../main.cpp" line="67"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly</source>
         <translation>Променливата &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; не е зададена правилно</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="71"/>
+        <location filename="../main.cpp" line="73"/>
         <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
         <translation>Не може да бъде намерен &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="76"/>
+        <location filename="../main.cpp" line="78"/>
         <source>Error</source>
         <translation>Грешка</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
